import { Meta, Canvas, Controls } from "@storybook/blocks";
import * as ComponentStories from "./software-updates.stories";

<Meta of={ComponentStories} name="Docs" />

# SoftwareUpdates

The `<ux-iws-software-updates>` component asynchronously displays information about a machines software. It handles machine software updates completely including requests to display the component, check machine information and handle a form to update machine subscriptions.

<Canvas of={ComponentStories.Default}></Canvas>

## Content API

### Software Update Types

```typescript
export enum Status {
    INSTALLATION_FAILED = "installation_failed",
    NOT_AVAILABLE_FOR_SUBSCRIPTION = "not_available_for_subscription",
    SUBSCRIBED = "subscribed",
    UNSUBSCRIBED = "unsubscribed",
    UPDATE_AVAILABLE = "update_available",
}
```

### Content Translations

All required translations must be passed as JSON string or object to the
`<ux-iws-software-updates>` component via the `translations` prop.

**Example Content Translations:**

```json
{
    "label": "Machine Software",
    "tooltip": {
        "copy": "Lorem ipsum dolor sit amet.",
        "linkText": "Mehr erfahren"
    },
    "state": {
        "subscribed": {
            "label": "Updates subscribed"
        },
        "unsubscribed": {
            "label": "Updates not subscribed",
            "button": "Activate Updates"
        },
        "update_available": {
            "label": "Updates available"
        },
        "installation_failed": {
            "label": "Installation has failed"
        },
        "not_available_for_subscription": {
            "label": ""
        }
    },
    "modalForm": {
        "headline": "Maschinen Software Updates",
        "copy": {
            "text1": "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit amet.",
            "text2": "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Consectetur adipiscing elit ullamco laboris nisi ut aliqua. Consectetur adipiscing elit ipsum. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Consectetur adipiscing elit ullamco laboris nisi ut aliqua. Consectetur adipiscing elit ipsum.",
            "linkText": "Read More"
        },
        "machine": {
            "label": "Machine"
        },
        "softwareUpdatesInput": {
            "label": "Select Update Type",
            "labelSwitchInput": "Security Updates"
        },
        "privacyPolicy": {
            "text": "Mit der Anmeldung der Updates akzeptieren Sie die",
            "linkText": "Trumpf Bedingungen für Machinensoftware Updates",
            "validationError": "This field is required"
        },
        "buttons": {
            "cancel": "Abbrechen",
            "submit": "Speichern"
        }
    },
    "modalMessageError": {
        "headline": "Something went wrong, please try again later.",
        "buttons": {
            "close": "Schliessen"
        }
    },
    "modalMessageSuccess": {
        "headline": "Your changes were saved",
        "buttons": {
            "close": "Schliessen"
        }
    }
}
```

## Developer Documentation

<Controls />
